@@ -27,11 +27,15 @@ Azure AD OAuth2 backend, docs at:
     https://python-social-auth.readthedocs.io/en/latest/backends/azuread.html
 """
 
+from __future__ import annotations
+
 import time
+from typing import Any
 
 import jwt
 
-from ..exceptions import AuthMissingParameter, AuthTokenError
+from social_core.exceptions import AuthMissingParameter, AuthTokenError
+
 from .oauth import BaseOAuth2
 
 
@@ -60,20 +64,20 @@ class AzureADOAuth2(BaseOAuth2):
         return self.setting("AUTHORITY_HOST", "login.microsoftonline.com")
 
     @property
-    def tenant_id(self):
+    def tenant_id(self) -> str:
         return "common"
 
     @property
-    def base_url(self):
+    def base_url(self) -> str:
         return self.BASE_URL.format(
             authority_host=self.authority_host, tenant_id=self.tenant_id
         )
 
-    def authorization_url(self):
-        return self.AUTHORIZATION_URL.format(base_url=self.base_url)
+    def get_authorization_url_format(self) -> dict[str, str]:
+        return {"base_url": self.base_url}
 
-    def access_token_url(self):
-        return self.ACCESS_TOKEN_URL.format(base_url=self.base_url)
+    def get_access_token_url_format(self) -> dict[str, str]:
+        return {"base_url": self.base_url}
 
     def get_user_id(self, details, response):
         """Use upn as unique id"""
@@ -119,10 +123,17 @@ class AzureADOAuth2(BaseOAuth2):
             extra_arguments.update({"resource": resource})
         return extra_arguments
 
-    def extra_data(self, user, uid, response, details=None, *args, **kwargs):
+    def extra_data(
+        self,
+        user,
+        uid: str,
+        response: dict[str, Any],
+        details: dict[str, Any],
+        pipeline_kwargs: dict[str, Any],
+    ) -> dict[str, Any]:
         """Return access_token and extra defined names to store in
         extra_data field"""
-        data = super().extra_data(user, uid, response, details, *args, **kwargs)
+        data = super().extra_data(user, uid, response, details, pipeline_kwargs)
         data["resource"] = self.setting("RESOURCE")
         return data
 
