@@ -27,16 +27,25 @@ See https://nicksnettravels.builttoroam.com/post/2017/01/24/Verifying-Azure-Acti
     for verifying JWT tokens.
 """
 
+from __future__ import annotations
+
 import json
+from typing import TYPE_CHECKING, Any, Literal
 
 from cryptography.hazmat.primitives import serialization
 from jwt import DecodeError, ExpiredSignatureError, get_unverified_header
 from jwt import decode as jwt_decode
-from jwt.algorithms import RSAAlgorithm
+from jwt.algorithms import RSAAlgorithm  # ty: ignore[possibly-unbound-import]
+
+from social_core.exceptions import AuthException, AuthTokenError
 
-from ..exceptions import AuthException, AuthTokenError
 from .azuread import AzureADOAuth2
 
+if TYPE_CHECKING:
+    from collections.abc import Mapping
+
+    from requests.auth import AuthBase
+
 
 class AzureADB2COAuth2(AzureADOAuth2):
     name = "azuread-b2c-oauth2"
@@ -92,24 +101,32 @@ class AzureADB2COAuth2(AzureADOAuth2):
             base_url=self.base_url, policy=self.policy
         )
 
-    def authorization_url(self):
-        # Policy is required, but added later by `auth_extra_arguments()`
-        return self.AUTHORIZATION_URL.format(base_url=self.base_url)
-
-    def access_token_url(self):
-        return self.ACCESS_TOKEN_URL.format(base_url=self.base_url, policy=self.policy)
+    def get_access_token_url_format(self) -> dict[str, str]:
+        params = super().get_access_token_url_format()
+        params["policy"] = self.policy
+        return params
 
     def jwks_url(self):
         return self.JWKS_URL.format(base_url=self.base_url, policy=self.policy)
 
-    def request_access_token(self, *args, **kwargs):
+    def request_access_token(
+        self,
+        url: str,
+        method: Literal["GET", "POST", "DELETE"] = "GET",
+        headers: Mapping[str, str | bytes] | None = None,
+        data: dict | bytes | str | None = None,
+        auth: tuple[str, str] | AuthBase | None = None,
+        params: dict | None = None,
+    ) -> dict[Any, Any]:
         """
         This is probably a hack, but otherwise AzureADOAuth2 expects
         `access_token`.
 
         However, B2C backends provides `id_token`.
         """
-        response = super().request_access_token(*args, **kwargs)
+        response = super().request_access_token(
+            url, method, headers, data, auth, params
+        )
         if "access_token" not in response:
             response["access_token"] = response["id_token"]
         return response
@@ -167,9 +184,9 @@ class AzureADB2COAuth2(AzureADOAuth2):
         raise DecodeError(f"Cannot find kid={kid}")
 
     def user_data(self, access_token, *args, **kwargs):
-        response = kwargs.get("response")
+        response = kwargs["response"]
 
-        id_token = response.get("id_token")
+        id_token = response["id_token"]
 
         # `kid` is short for key id
         kid = get_unverified_header(id_token)["kid"]
