@@ -4,16 +4,18 @@ import time
 from typing import TYPE_CHECKING, Any, Literal, cast
 
 import requests
-from requests import Response
 
-from ..exceptions import AuthConnectionError, AuthUnknownError
-from ..utils import module_member, parse_qs, user_agent
+from social_core.exceptions import AuthConnectionError, AuthUnknownError
+from social_core.utils import module_member, parse_qs, social_logger, user_agent
 
 if TYPE_CHECKING:
     from collections.abc import Mapping
 
+    from requests import Response
     from requests.auth import AuthBase
 
+    from social_core.storage import UserProtocol
+
 
 class BaseAuth:
     """A authentication backend that authenticates the user based on
@@ -25,15 +27,21 @@ class BaseAuth:
     EXTRA_DATA: list[str | tuple[str, str] | tuple[str, str, bool]] | None = None
     GET_ALL_EXTRA_DATA = False
     REQUIRES_EMAIL_VALIDATION = False
-    SEND_USER_AGENT = False
+    SEND_USER_AGENT = True
 
-    def __init__(self, strategy, redirect_uri=None):
+    def __init__(self, strategy, redirect_uri=None) -> None:
         self.strategy = strategy
         self.redirect_uri = redirect_uri
         self.data = self.strategy.request_data()
         self.redirect_uri = self.strategy.absolute_uri(self.redirect_uri)
 
-    def setting(self, name, default=None):
+    def log_debug(self, message, *args) -> None:
+        social_logger.debug(f"{self.name}: {message}", *args)
+
+    def log_warning(self, message, *args) -> None:
+        social_logger.warning(f"{self.name}: {message}", *args)
+
+    def setting(self, name: str, default=None):
         """Return setting value from strategy"""
         return self.strategy.setting(name, default=default, backend=self)
 
@@ -45,19 +53,19 @@ class BaseAuth:
     def complete(self, *args, **kwargs):
         return self.auth_complete(*args, **kwargs)
 
-    def auth_url(self):
+    def auth_url(self) -> str:
         """Must return redirect URL to auth provider"""
         raise NotImplementedError("Implement in subclass")
 
-    def auth_html(self):
+    def auth_html(self) -> str:
         """Must return login HTML content returned by provider"""
-        raise NotImplementedError("Implement in subclass")
+        return "Implement in subclass"
 
     def auth_complete(self, *args, **kwargs):
         """Completes login process, must return user instance"""
         raise NotImplementedError("Implement in subclass")
 
-    def process_error(self, data):
+    def process_error(self, data) -> None:
         """Process data for errors, raise exception if needed.
         Call this method on any override of auth_complete."""
 
@@ -104,7 +112,7 @@ class BaseAuth:
         kwargs["user_storage"] = self.strategy.storage.user
         return self.run_pipeline(pipeline, *args, **kwargs)
 
-    def run_pipeline(self, pipeline, pipeline_index=0, *args, **kwargs):
+    def run_pipeline(self, pipeline: list[str], pipeline_index=0, *args, **kwargs):
         out = kwargs.copy()
         out.setdefault("strategy", self.strategy)
         out.setdefault("backend", out.pop(self.name, None) or self)
@@ -129,19 +137,20 @@ class BaseAuth:
 
     def extra_data(
         self,
-        user,
+        user: UserProtocol | None,
         uid: str,
         response: dict[str, Any],
         details: dict[str, Any],
-        *args,
-        **kwargs,
+        pipeline_kwargs: dict[str, Any],
     ) -> dict[str, Any]:
         """Return default extra data to store in extra_data field"""
         data: dict[str, Any] = {
             # store the last time authentication took place
             "auth_time": int(time.time())
         }
-        extra_data_entries: list[str | tuple[str, str] | tuple[str, str, bool]] = []
+        extra_data_entries: (
+            list[str] | list[str | tuple[str, str] | tuple[str, str, bool]]
+        ) = []
         if self.GET_ALL_EXTRA_DATA or self.setting("GET_ALL_EXTRA_DATA", False):
             extra_data_entries = list(response.keys())
         else:
@@ -187,7 +196,7 @@ class BaseAuth:
         response."""
         return response.get(self.ID_KEY)
 
-    def get_user_details(self, response):
+    def get_user_details(self, response) -> dict[str, Any]:
         """Must return user details in a know internal struct:
         {'username': <username if any>,
          'email': <user email if any>,
@@ -221,10 +230,10 @@ class BaseAuth:
     def continue_pipeline(self, partial):
         """Continue previous halted pipeline"""
         return self.strategy.authenticate(
-            self, pipeline_index=partial.next_step, *partial.args, **partial.kwargs
+            self, *partial.args, pipeline_index=partial.next_step, **partial.kwargs
         )
 
-    def auth_extra_arguments(self):
+    def auth_extra_arguments(self) -> dict[str, str]:
         """Return extra arguments needed on auth process. The defaults can be
         overridden by GET parameters."""
         extra_arguments = self.setting("AUTH_EXTRA_ARGUMENTS", {}).copy()
