@@ -2,9 +2,10 @@
 Google App Engine support using User API
 """
 
-from google.appengine.api import users
+from google.appengine.api import users  # ty: ignore[unresolved-import]
+
+from social_core.exceptions import AuthException
 
-from ..exceptions import AuthException
 from .base import BaseAuth
 
 
