@@ -3,8 +3,9 @@ Jawbone OAuth2 backend, docs at:
     https://python-social-auth.readthedocs.io/en/latest/backends/jawbone.html
 """
 
-from ..exceptions import AuthCanceled, AuthUnknownError
-from ..utils import handle_http_errors
+from social_core.exceptions import AuthCanceled, AuthUnknownError
+from social_core.utils import handle_http_errors
+
 from .oauth import BaseOAuth2
 
 
@@ -71,5 +72,5 @@ class JawboneOAuth2(BaseOAuth2):
         )
         self.process_error(response)
         return self.do_auth(
-            response["access_token"], response=response, *args, **kwargs
+            response["access_token"], *args, response=response, **kwargs
         )
