@@ -1,6 +1,7 @@
 from requests.auth import HTTPBasicAuth
 
-from ..utils import handle_http_errors
+from social_core.utils import handle_http_errors
+
 from .oauth import BaseOAuth2
 
 
@@ -56,5 +57,5 @@ class JustGivingOAuth2(BaseOAuth2):
         )
         self.process_error(response)
         return self.do_auth(
-            response["access_token"], response=response, *args, **kwargs
+            response["access_token"], *args, response=response, **kwargs
         )
