@@ -3,14 +3,22 @@ LinkedIn OAuth1 and OAuth2 backend, docs at:
     https://python-social-auth.readthedocs.io/en/latest/backends/linkedin.html
 """
 
+from __future__ import annotations
+
 import datetime
 from calendar import timegm
+from typing import TYPE_CHECKING, Any, Literal, cast
 
 from social_core.backends.open_id_connect import OpenIdConnectAuth
 from social_core.exceptions import AuthCanceled, AuthTokenError
 
 from .oauth import BaseOAuth2
 
+if TYPE_CHECKING:
+    from collections.abc import Mapping
+
+    from requests.auth import AuthBase
+
 
 class LinkedinOpenIdConnect(OpenIdConnectAuth):
     """
@@ -27,7 +35,7 @@ class LinkedinOpenIdConnect(OpenIdConnectAuth):
     # else our request falls back to basic auth which is not supported.
     TOKEN_ENDPOINT_AUTH_METHOD = "client_secret_post"
 
-    def validate_claims(self, id_token):
+    def validate_claims(self, id_token) -> None:
         """Copy of the regular validate_claims method without the nonce validation."""
 
         utc_timestamp = timegm(datetime.datetime.now(datetime.timezone.utc).timetuple())
@@ -48,13 +56,13 @@ class LinkedinOAuth2(BaseOAuth2):
     name = "linkedin-oauth2"
     AUTHORIZATION_URL = "https://www.linkedin.com/oauth/v2/authorization"
     ACCESS_TOKEN_URL = "https://www.linkedin.com/oauth/v2/accessToken"
-    USER_DETAILS_URL = "https://api.linkedin.com/v2/userinfo?projection=({projection})"
+    USER_DETAILS_URL = "https://api.linkedin.com/v2/me?projection=({projection})"
     USER_EMAILS_URL = (
         "https://api.linkedin.com/v2/emailAddress"
         "?q=members&projection=(elements*(handle~))"
     )
     REDIRECT_STATE = False
-    DEFAULT_SCOPE = ["email", "profile", "openid"]
+    DEFAULT_SCOPE = ["r_liteprofile"]
     EXTRA_DATA = [
         ("id", "id"),
         ("expires_in", "expires"),
@@ -65,7 +73,14 @@ class LinkedinOAuth2(BaseOAuth2):
     ]
 
     def user_details_url(self):
-        return self.USER_DETAILS_URL
+        # use set() since LinkedIn fails when values are duplicated
+        fields_selectors = list(
+            {"id", "firstName", "lastName", *self.setting("FIELD_SELECTORS", [])}
+        )
+        # user sort to ease the tests URL mocking
+        fields_selectors.sort()
+        fields_selectors = ",".join(fields_selectors)
+        return self.USER_DETAILS_URL.format(projection=fields_selectors)
 
     def user_emails_url(self):
         return self.USER_EMAILS_URL
@@ -75,10 +90,10 @@ class LinkedinOAuth2(BaseOAuth2):
             self.user_details_url(), headers=self.user_data_headers(access_token)
         )
 
-        if "email" in set(self.setting("FIELD_SELECTORS", [])):
+        if "emailAddress" in set(self.setting("FIELD_SELECTORS", [])):
             emails = self.email_data(access_token, *args, **kwargs)
             if emails:
-                response["email"] = emails[0]
+                response["emailAddress"] = emails[0]
 
         return response
 
@@ -88,20 +103,38 @@ class LinkedinOAuth2(BaseOAuth2):
         )
         email_addresses = []
         for element in response.get("elements", []):
-            email_address = element.get("handle~", {}).get("email")
+            email_address = element.get("handle~", {}).get("emailAddress")
             email_addresses.append(email_address)
         return list(filter(None, email_addresses))
 
     def get_user_details(self, response):
         """Return user details from Linkedin account"""
-        response = self.user_data(access_token=response["access_token"])
+
+        def get_localized_name(name):
+            """
+            FirstName & Last Name object
+            {
+                  'localized': {
+                     'en_US': 'Smith'
+                  },
+                  'preferredLocale': {
+                     'country': 'US',
+                     'language': 'en'
+                  }
+            }
+            :return the localizedName from the lastName object
+            """
+            locale = "{}_{}".format(
+                name["preferredLocale"]["language"], name["preferredLocale"]["country"]
+            )
+            return name["localized"].get(locale, "")
+
         fullname, first_name, last_name = self.get_user_names(
-            first_name=response["given_name"],
-            last_name=response["family_name"],
+            first_name=get_localized_name(response["firstName"]),
+            last_name=get_localized_name(response["lastName"]),
         )
-        email = response.get("email", "")
+        email = response.get("emailAddress", "")
         return {
-            "id": response.get("sub", ""),
             "username": first_name + last_name,
             "fullname": fullname,
             "first_name": first_name,
@@ -119,13 +152,22 @@ class LinkedinOAuth2(BaseOAuth2):
         headers["Authorization"] = f"Bearer {access_token}"
         return headers
 
-    def request_access_token(self, *args, **kwargs):
+    def request_access_token(
+        self,
+        url: str,
+        method: Literal["GET", "POST", "DELETE"] = "GET",
+        headers: Mapping[str, str | bytes] | None = None,
+        data: dict | bytes | str | None = None,
+        auth: tuple[str, str] | AuthBase | None = None,
+        params: dict | None = None,
+    ) -> dict[Any, Any]:
         # LinkedIn expects a POST request with querystring parameters, despite
         # the spec http://tools.ietf.org/html/rfc6749#section-4.1.3
-        kwargs["params"] = kwargs.pop("data")
-        return super().request_access_token(*args, **kwargs)
+        return super().request_access_token(
+            url, method, headers, data, auth, cast("dict", data)
+        )
 
-    def process_error(self, data):
+    def process_error(self, data) -> None:
         super().process_error(data)
         if data.get("serviceErrorCode"):
             raise AuthCanceled(self, data.get("message") or data.get("status"))
