@@ -8,7 +8,7 @@ from urllib.parse import urlencode
 from oauthlib.oauth1 import SIGNATURE_TYPE_AUTH_HEADER
 from requests_oauthlib import OAuth1
 
-from ..exceptions import (
+from social_core.exceptions import (
     AuthCanceled,
     AuthException,
     AuthFailed,
@@ -18,12 +18,14 @@ from ..exceptions import (
     AuthTokenError,
     AuthUnknownError,
 )
-from ..utils import (
+from social_core.utils import (
     constant_time_compare,
     handle_http_errors,
     parse_qs,
     url_add_parameters,
+    wrap_access_token_error,
 )
+
 from .base import BaseAuth
 
 if TYPE_CHECKING:
@@ -59,11 +61,18 @@ class OAuthAuth(BaseAuth):
     REDIRECT_STATE = False
     STATE_PARAMETER = False
 
-    def extra_data(self, user, uid, response, details=None, *args, **kwargs):
+    def extra_data(
+        self,
+        user,
+        uid: str,
+        response: dict[str, Any],
+        details: dict[str, Any],
+        pipeline_kwargs: dict[str, Any],
+    ) -> dict[str, Any]:
         """Return access_token and extra defined names to store in
         extra_data field"""
-        data = super().extra_data(user, uid, response, details, *args, **kwargs)
-        data["access_token"] = response.get("access_token", "") or kwargs.get(
+        data = super().extra_data(user, uid, response, details, pipeline_kwargs)
+        data["access_token"] = response.get("access_token") or pipeline_kwargs.get(
             "access_token"
         )
         return data
@@ -138,13 +147,25 @@ class OAuthAuth(BaseAuth):
         return {}
 
     def authorization_url(self) -> str:
-        return self.AUTHORIZATION_URL
+        url = self.setting("AUTHORIZATION_URL", self.AUTHORIZATION_URL)
+        if format_params := self.get_authorization_url_format():
+            return url.format(**format_params)
+        return url
+
+    def get_authorization_url_format(self) -> dict[str, str]:
+        return {}
 
     def access_token_url(self) -> str:
-        return self.ACCESS_TOKEN_URL
+        url = self.setting("ACCESS_TOKEN_URL", self.ACCESS_TOKEN_URL)
+        if format_params := self.get_access_token_url_format():
+            return url.format(**format_params)
+        return url
+
+    def get_access_token_url_format(self) -> dict[str, str]:
+        return {}
 
     def revoke_token_url(self, token, uid) -> str:
-        return self.REVOKE_TOKEN_URL
+        return self.setting("REVOKE_TOKEN_URL", self.REVOKE_TOKEN_URL)
 
     def revoke_token_params(self, token, uid) -> dict[str, Any]:
         return {}
@@ -186,12 +207,12 @@ class BaseOAuth1(OAuthAuth):
     REDIRECT_URI_PARAMETER_NAME = "redirect_uri"
     UNATHORIZED_TOKEN_SUFIX = "unauthorized_token_name"
 
-    def auth_url(self) -> str | bytes | None:
+    def auth_url(self) -> str:
         """Return redirect url"""
         token = self.set_unauthorized_token()
         return self.oauth_authorization_request(token)
 
-    def process_error(self, data):
+    def process_error(self, data) -> None:
         if "oauth_problem" in data:
             if data["oauth_problem"] == "user_refused":
                 raise AuthCanceled(self, "User refused the access")
@@ -280,8 +301,8 @@ class BaseOAuth1(OAuthAuth):
             token = parse_qs(token)
         params = self.auth_extra_arguments() or {}
         params.update(self.get_scope_argument())
-        params[self.OAUTH_TOKEN_PARAMETER_NAME] = token.get(
-            self.OAUTH_TOKEN_PARAMETER_NAME
+        params[self.OAUTH_TOKEN_PARAMETER_NAME] = cast(
+            "str", token.get(self.OAUTH_TOKEN_PARAMETER_NAME)
         )
         state = self.get_or_create_state()
         params[self.REDIRECT_URI_PARAMETER_NAME] = self.get_redirect_uri(state)
@@ -351,7 +372,7 @@ class BaseOAuth2(OAuthAuth):
         return self.USE_BASIC_AUTH
 
     def auth_params(self, state: str | None = None) -> dict[str, str]:
-        client_id, client_secret = self.get_key_and_secret()
+        client_id, _client_secret = self.get_key_and_secret()
         params = {"client_id": client_id, "redirect_uri": self.get_redirect_uri(state)}
         if self.STATE_PARAMETER and state:
             params["state"] = state
@@ -359,7 +380,7 @@ class BaseOAuth2(OAuthAuth):
             params["response_type"] = self.RESPONSE_TYPE
         return params
 
-    def auth_url(self) -> str | bytes | None:
+    def auth_url(self) -> str:
         """Return redirect url"""
         state = self.get_or_create_state()
         params = self.auth_params(state)
@@ -399,11 +420,20 @@ class BaseOAuth2(OAuthAuth):
             "Accept": "application/json",
         }
 
-    def extra_data(self, user, uid, response, details, *args, **kwargs):
+    def extra_data(
+        self,
+        user,
+        uid: str,
+        response: dict[str, Any],
+        details: dict[str, Any],
+        pipeline_kwargs: dict[str, Any],
+    ) -> dict[str, Any]:
         """Return access_token, token_type, and extra defined names to store in
         extra_data field"""
-        data = super().extra_data(user, uid, response, details=details, *args, **kwargs)
-        data["token_type"] = response.get("token_type") or kwargs.get("token_type")
+        data = super().extra_data(user, uid, response, details, pipeline_kwargs)
+        data["token_type"] = response.get("token_type") or pipeline_kwargs.get(
+            "token_type"
+        )
         return data
 
     def request_access_token(
@@ -415,11 +445,12 @@ class BaseOAuth2(OAuthAuth):
         auth: tuple[str, str] | AuthBase | None = None,
         params: dict | None = None,
     ) -> dict[Any, Any]:
-        return self.get_json(
-            url, method=method, headers=headers, data=data, auth=auth, params=params
-        )
+        with wrap_access_token_error(self):
+            return self.get_json(
+                url, method=method, headers=headers, data=data, auth=auth, params=params
+            )
 
-    def process_error(self, data):
+    def process_error(self, data) -> None:
         if data.get("error"):
             if "denied" in data["error"] or "cancelled" in data["error"]:
                 raise AuthCanceled(self, data.get("error_description", ""))
@@ -448,7 +479,7 @@ class BaseOAuth2(OAuthAuth):
         )
         self.process_error(response)
         return self.do_auth(
-            response["access_token"], response=response, *args, **kwargs
+            response["access_token"], *args, response=response, **kwargs
         )
 
     @handle_http_errors
