@@ -4,7 +4,7 @@ import base64
 import datetime
 import json
 from calendar import timegm
-from typing import Any
+from typing import TYPE_CHECKING, Any, Literal
 
 import jwt
 from jwt import (
@@ -16,14 +16,27 @@ from jwt import (
 from jwt.utils import base64url_decode
 
 from social_core.backends.oauth import BaseOAuth2
-from social_core.exceptions import AuthMissingParameter, AuthTokenError
+from social_core.exceptions import (
+    AuthInvalidParameter,
+    AuthMissingParameter,
+    AuthNotImplementedParameter,
+    AuthTokenError,
+)
 from social_core.utils import cache
 
+if TYPE_CHECKING:
+    from collections.abc import Mapping
+
+    from requests.auth import AuthBase
+
+from cryptography.hazmat.backends import default_backend
+from cryptography.hazmat.primitives import hashes
+
 
 class OpenIdConnectAssociation:
     """Use Association model to save the nonce by force."""
 
-    def __init__(self, handle, secret="", issued=0, lifetime=0, assoc_type=""):
+    def __init__(self, handle, secret="", issued=0, lifetime=0, assoc_type="") -> None:
         self.handle = handle  # as nonce
         self.secret = secret.encode()  # not use
         self.issued = issued  # not use
@@ -56,6 +69,9 @@ class OpenIdConnectAuth(BaseOAuth2):
     USERNAME_KEY = "preferred_username"
     JWT_ALGORITHMS = ["RS256"]
     JWT_DECODE_OPTIONS: dict[str, Any] = {}
+    JWT_LEEWAY: float = 1.0  # seconds
+    VALIDATE_AT_HASH: bool = True
+    CUSTOM_AT_HASH_ALGO: str | None = None
     # When these options are unspecified, server will choose via openid autoconfiguration
     ID_TOKEN_ISSUER = ""
     ACCESS_TOKEN_URL = ""
@@ -64,8 +80,16 @@ class OpenIdConnectAuth(BaseOAuth2):
     USERINFO_URL = ""
     JWKS_URI = ""
     TOKEN_ENDPOINT_AUTH_METHOD = ""
+    # Optional parameters for Authentication Request
+    DISPLAY = None
+    PROMPT = None
+    MAX_AGE = None
+    UI_LOCALES = None
+    ID_TOKEN_HINT = None
+    LOGIN_HINT = None
+    ACR_VALUES = None
 
-    def __init__(self, *args, **kwargs):
+    def __init__(self, *args, **kwargs) -> None:
         self.id_token = None
         super().__init__(*args, **kwargs)
 
@@ -136,10 +160,59 @@ class OpenIdConnectAuth(BaseOAuth2):
         response = self.request(self.jwks_uri())
         return json.loads(response.text)["keys"]
 
-    def auth_params(self, state=None):
+    def auth_params(self, state=None):  # noqa: C901
         """Return extra arguments needed on auth process."""
         params = super().auth_params(state)
         params["nonce"] = self.get_and_store_nonce(self.authorization_url(), state)
+
+        display = self.setting("DISPLAY", default=self.DISPLAY)
+        if display is not None:
+            if not display:
+                raise AuthMissingParameter(
+                    self, "OpenID Connect display value cannot be empty string."
+                )
+
+            if display not in ("page", "popup", "touch", "wap"):
+                raise AuthMissingParameter(
+                    self, f"Invalid OpenID Connect display value: {display}"
+                )
+
+            params["display"] = display
+
+        prompt = self.setting("PROMPT", default=self.PROMPT)
+        if prompt is not None:
+            if not prompt:
+                raise AuthInvalidParameter(self, "prompt")
+
+            for prompt_token in prompt.split():
+                if prompt_token not in ("none", "login", "consent", "select_account"):
+                    raise AuthInvalidParameter(self, "prompt")
+
+            params["prompt"] = prompt
+
+        max_age = self.setting("MAX_AGE", default=self.MAX_AGE)
+        if max_age is not None:
+            if max_age < 0:
+                raise AuthInvalidParameter(self, "max_age")
+
+            params["max_age"] = max_age
+
+        ui_locales = self.setting("UI_LOCALES", default=self.UI_LOCALES)
+        if ui_locales is not None:
+            raise AuthNotImplementedParameter(self, "ui_locales")
+
+        id_token_hint = self.setting("ID_TOKEN_HINT", default=self.ID_TOKEN_HINT)
+        if id_token_hint is not None:
+            raise AuthNotImplementedParameter(self, "id_token_hint")
+
+        login_hint = self.setting("LOGIN_HINT", default=self.LOGIN_HINT)
+        if login_hint is not None:
+            raise AuthNotImplementedParameter(self, "login_hint")
+
+        acr_values = self.setting("ACR_VALUES", default=self.ACR_VALUES)
+        if acr_values is not None:
+            raise AuthNotImplementedParameter(self, "acr_values")
+
         return params
 
     def get_and_store_nonce(self, url, state):
@@ -158,10 +231,10 @@ class OpenIdConnectAuth(BaseOAuth2):
         except IndexError:
             pass
 
-    def remove_nonce(self, nonce_id):
+    def remove_nonce(self, nonce_id) -> None:
         self.strategy.storage.association.remove([nonce_id])
 
-    def validate_claims(self, id_token):
+    def validate_claims(self, id_token) -> None:
         utc_timestamp = timegm(datetime.datetime.now(datetime.timezone.utc).timetuple())
 
         if "nbf" in id_token and utc_timestamp < id_token["nbf"]:
@@ -216,7 +289,7 @@ class OpenIdConnectAuth(BaseOAuth2):
         Validates the id_token according to the steps at
         http://openid.net/specs/openid-connect-core-1_0.html#IDTokenValidation.
         """
-        client_id, client_secret = self.get_key_and_secret()
+        client_id, _client_secret = self.get_key_and_secret()
 
         key = self.find_valid_key(id_token)
 
@@ -233,6 +306,7 @@ class OpenIdConnectAuth(BaseOAuth2):
                 audience=client_id,
                 issuer=self.id_token_issuer(),
                 options=self.setting("JWT_DECODE_OPTIONS", self.JWT_DECODE_OPTIONS),
+                leeway=self.setting("JWT_LEEWAY", self.JWT_LEEWAY),
             )
         except ExpiredSignatureError:
             raise AuthTokenError(self, "Signature has expired")
@@ -246,21 +320,29 @@ class OpenIdConnectAuth(BaseOAuth2):
 
         # pyjwt does not validate OIDC claims
         # see https://github.com/jpadilla/pyjwt/pull/296
-        if "at_hash" in claims and claims["at_hash"] != self.calc_at_hash(
-            access_token, key["alg"]
-        ):
+        if not self.validate_at_hash(claims, access_token, key):
             raise AuthTokenError(self, "Invalid access token")
 
         self.validate_claims(claims)
 
         return claims
 
-    def request_access_token(self, *args, **kwargs):
+    def request_access_token(
+        self,
+        url: str,
+        method: Literal["GET", "POST", "DELETE"] = "GET",
+        headers: Mapping[str, str | bytes] | None = None,
+        data: dict | bytes | str | None = None,
+        auth: tuple[str, str] | AuthBase | None = None,
+        params: dict | None = None,
+    ) -> dict[Any, Any]:
         """
         Retrieve the access token. Also, validate the id_token and
         store it (temporarily).
         """
-        response = self.get_json(*args, **kwargs)
+        response = super().request_access_token(
+            url, method, headers, data, auth, params
+        )
         self.id_token = self.validate_and_return_id_token(
             response["id_token"], response["access_token"]
         )
@@ -273,25 +355,68 @@ class OpenIdConnectAuth(BaseOAuth2):
 
     def get_user_details(self, response):
         username_key = self.setting("USERNAME_KEY", self.USERNAME_KEY)
+
+        def get_value(key):
+            if key in response:
+                return response.get(key)
+            if self.id_token is not None:
+                return self.id_token.get(key)
+            return None
+
         return {
-            "username": response.get(username_key),
-            "email": response.get("email"),
-            "fullname": response.get("name"),
-            "first_name": response.get("given_name"),
-            "last_name": response.get("family_name"),
+            "username": get_value(username_key),
+            "email": get_value("email"),
+            "fullname": get_value("name"),
+            "first_name": get_value("given_name"),
+            "last_name": get_value("family_name"),
         }
 
+    def validate_at_hash(self, claims, access_token, key):
+        """
+        Validate the 'at_hash' claim according to OpenID Connect specs.
+
+        See: https://openid.net/specs/openid-connect-core-1_0.html#CodeIDToken
+        """
+
+        if not self.VALIDATE_AT_HASH:
+            return True
+        if "at_hash" not in claims:
+            return True
+
+        expected_hash = claims["at_hash"]
+        calculated_hash = self.calc_at_hash(
+            access_token, key["alg"], self.CUSTOM_AT_HASH_ALGO
+        )
+        return expected_hash == calculated_hash
+
     @staticmethod
-    def calc_at_hash(access_token, algorithm):
+    def calc_at_hash(access_token, algorithm, custom_at_hash_algo: str | None = None):
         """
         Calculates "at_hash" claim which is not done by pyjwt.
+        Custom "at_hash" algorithm is used for non-standard token.
 
         See https://pyjwt.readthedocs.io/en/stable/usage.html#oidc-login-flow
+        See https://github.com/python-social-auth/social-core/issues/1306
         """
-        alg_obj = jwt.get_algorithm_by_name(algorithm)
-        digest = alg_obj.compute_hash_digest(access_token.encode("utf-8"))
-        return (
-            base64.urlsafe_b64encode(digest[: (len(digest) // 2)])
-            .decode("utf-8")
-            .rstrip("=")
-        )
+
+        if not custom_at_hash_algo:
+            alg_obj = jwt.get_algorithm_by_name(algorithm)
+            digest = alg_obj.compute_hash_digest(access_token.encode("utf-8"))
+            return (
+                base64.urlsafe_b64encode(digest[: (len(digest) // 2)])
+                .decode("utf-8")
+                .rstrip("=")
+            )
+
+        algo_class_name = custom_at_hash_algo.upper()
+        algo_class = getattr(hashes, algo_class_name, None)
+        if algo_class is None:
+            raise NotImplementedError(
+                f"Unsupported custom at hash algorithm: {custom_at_hash_algo}"
+            )
+
+        hasher = hashes.Hash(algo_class(), backend=default_backend())
+        hasher.update(access_token.encode("utf-8"))
+        digest = hasher.finalize()
+        half = digest[: (len(digest) // 2)]
+        return base64.urlsafe_b64encode(half).decode("utf-8").rstrip("=")
