@@ -4,7 +4,8 @@ Openshift OAuth2 backend
 
 from urllib.parse import urljoin
 
-from ..utils import append_slash
+from social_core.utils import append_slash
+
 from .oauth import BaseOAuth2
 
 
