@@ -3,7 +3,12 @@ Pocket OAuth2 backend, docs at:
     https://python-social-auth.readthedocs.io/en/latest/backends/pocket.html
 """
 
-from ..utils import handle_http_errors
+from __future__ import annotations
+
+from typing import Any
+
+from social_core.utils import handle_http_errors
+
 from .base import BaseAuth
 
 
@@ -22,10 +27,17 @@ class PocketAuth(BaseAuth):
     def get_user_details(self, response):
         return {"username": response["username"]}
 
-    def extra_data(self, user, uid, response, details=None, *args, **kwargs):
+    def extra_data(
+        self,
+        user,
+        uid: str,
+        response: dict[str, Any],
+        details: dict[str, Any],
+        pipeline_kwargs: dict[str, Any],
+    ) -> dict[str, Any]:
         return response
 
-    def auth_url(self):
+    def auth_url(self) -> str:
         data = {
             "consumer_key": self.setting("KEY"),
             "redirect_uri": self.redirect_uri,
