@@ -8,12 +8,20 @@ Terminology:
                            users via SAML
 """
 
+from __future__ import annotations
+
 import json
+from typing import Any
 
 from onelogin.saml2.auth import OneLogin_Saml2_Auth
 from onelogin.saml2.settings import OneLogin_Saml2_Settings
 
-from ..exceptions import AuthFailed, AuthMissingParameter
+from social_core.exceptions import (
+    AuthFailed,
+    AuthInvalidParameter,
+    AuthMissingParameter,
+)
+
 from .base import BaseAuth
 
 # Helpful constants:
@@ -26,12 +34,62 @@ OID_SURNAME = "urn:oid:2.5.4.4"
 OID_USERID = "urn:oid:0.9.2342.19200300.100.1.1"
 
 
+FULLNAME_FIELDS = (
+    OID_COMMON_NAME,
+    "http://schemas.xmlsoap.org/claims/CommonName",
+    "http://schemas.xmlsoap.org/ws/2005/05/identity/claims/fullname",
+    "http://schemas.microsoft.com/identity/claims/displayname",
+    "full_name",
+    "fullname",
+    "fullName",
+)
+
+FIRST_NAME_FIELDS = (
+    OID_GIVEN_NAME,
+    "http://schemas.xmlsoap.org/ws/2005/05/identity/claims/givenname",
+    "first_name",
+    "firstname",
+    "firstName",
+    "given_name",
+    "givenname",
+    "givenName",
+)
+LAST_NAME_FIELDS = (
+    OID_SURNAME,
+    "http://schemas.xmlsoap.org/ws/2005/05/identity/claims/surname",
+    "last_name",
+    "lastname",
+    "lastName",
+    "surname",
+)
+EMAIL_FIELDS = (
+    OID_MAIL,
+    "http://schemas.xmlsoap.org/claims/EmailAddress",
+    "http://schemas.xmlsoap.org/ws/2005/05/identity/claims/emailaddress",
+    "email",
+    "mail",
+)
+
+USERNAME_FIELDS = (
+    OID_USERID,
+    "http://schemas.xmlsoap.org/ws/2005/05/identity/claims/name",
+    "subjectNameID",
+    "username",
+)
+
+PERSISTENT_FIELDS = (
+    OID_USERID,
+    "name_id",
+)
+
+
 class SAMLIdentityProvider:
     """Wrapper around configuration for a SAML Identity provider"""
 
-    def __init__(self, name, **kwargs):
+    def __init__(self, backend: BaseAuth, name: str, **kwargs) -> None:
         """Load and parse configuration"""
-        self.name = name
+        self.backend: BaseAuth = backend
+        self.name: str = name
         # name should be a slug and must not contain a colon, which
         # could conflict with uid prefixing:
         assert ":" not in self.name and " " not in self.name, (
@@ -39,7 +97,9 @@ class SAMLIdentityProvider:
         )
         self.conf = kwargs
 
-    def get_user_permanent_id(self, attributes):
+    def get_user_permanent_id(
+        self, attributes: dict[str, str | list[str] | None]
+    ) -> str:
         """
         The most important method: Get a permanent, unique identifier
         for this user from the attributes supplied by the IdP.
@@ -47,36 +107,77 @@ class SAMLIdentityProvider:
         If you want to use the NameID, it's available via
         attributes['name_id']
         """
-        uid = attributes[self.conf.get("attr_user_permanent_id", OID_USERID)]
-        if isinstance(uid, list):
-            uid = uid[0]
+        setting = "attr_user_permanent_id"
+        uid = self.get_attr(attributes, setting, PERSISTENT_FIELDS)
+        if not uid:
+            raise AuthInvalidParameter(self.backend, "attr_user_permanent_id")
         return uid
 
     # Attributes processing:
-    def get_user_details(self, attributes):
+    def get_user_details(
+        self, attributes: dict[str, str | list[str] | None]
+    ) -> dict[str, str | None]:
         """
         Given the SAML attributes extracted from the SSO response, get
         the user data like name.
         """
         return {
-            "fullname": self.get_attr(attributes, "attr_full_name", OID_COMMON_NAME),
-            "first_name": self.get_attr(attributes, "attr_first_name", OID_GIVEN_NAME),
-            "last_name": self.get_attr(attributes, "attr_last_name", OID_SURNAME),
-            "username": self.get_attr(attributes, "attr_username", OID_USERID),
-            "email": self.get_attr(attributes, "attr_email", OID_MAIL),
+            "fullname": self.get_attr(attributes, "attr_full_name", FULLNAME_FIELDS),
+            "first_name": self.get_attr(
+                attributes, "attr_first_name", FIRST_NAME_FIELDS
+            ),
+            "last_name": self.get_attr(attributes, "attr_last_name", LAST_NAME_FIELDS),
+            "username": self.get_attr(attributes, "attr_username", USERNAME_FIELDS),
+            "email": self.get_attr(attributes, "attr_email", EMAIL_FIELDS),
         }
 
-    def get_attr(self, attributes, conf_key, default_attribute):
+    def get_attr(
+        self,
+        attributes: dict[str, str | list[str] | None],
+        conf_key: str,
+        default_attributes: tuple[str, ...],
+        *,
+        validate_defaults: bool = False,
+    ) -> str | None:
         """
         Internal helper method.
         Get the attribute 'default_attribute' out of the attributes,
         unless self.conf[conf_key] overrides the default by specifying
         another attribute to use.
         """
-        key = self.conf.get(conf_key, default_attribute)
-        value = attributes.get(key, None)
+        validate = True
+
+        try:
+            # Use configured value
+            attribute_name = self.conf[conf_key]
+        except KeyError:
+            # Find first matching attribute from default ones
+            for attribute_name in default_attributes:
+                if attribute_name in attributes:
+                    break
+            else:
+                return None
+            validate = validate_defaults
+        else:
+            # Value explicitly set to None, ignore the attribute
+            if attribute_name is None:
+                return None
+
+        try:
+            value = attributes[attribute_name]
+        except KeyError as error:
+            if validate:
+                # Fail if configured or required attribute is not present
+                raise AuthMissingParameter(
+                    self.backend,
+                    f"{attribute_name} (configured by {conf_key})",
+                ) from error
+            return None
+
+        # Convert values list to the first value (if present)
         if isinstance(value, list):
             value = value[0] if value else None
+
         return value
 
     @property
@@ -127,24 +228,6 @@ class SAMLIdentityProvider:
         raise KeyError("IDP must contain x509cert or x509certMulti")
 
 
-class DummySAMLIdentityProvider(SAMLIdentityProvider):
-    """
-    A placeholder IdP used when we must specify something, e.g. when
-    generating SP metadata.
-
-    If OneLogin_Saml2_Auth is modified to not always require IdP
-    config, this can be removed.
-    """
-
-    def __init__(self):
-        super().__init__(
-            "dummy",
-            entity_id="https://dummy.none/saml2",
-            url="https://dummy.none/SSO",
-            x509cert="",
-        )
-
-
 class SAMLAuth(BaseAuth):
     """
     PSA Backend that implements SAML 2.0 Service Provider (SP) functionality.
@@ -192,12 +275,19 @@ class SAMLAuth(BaseAuth):
     name = "saml"
     EXTRA_DATA = []
 
-    def get_idp(self, idp_name):
+    def get_idp(self, idp_name: str | None) -> SAMLIdentityProvider:
         """Given the name of an IdP, get a SAMLIdentityProvider instance"""
-        idp_config = self.setting("ENABLED_IDPS")[idp_name]
-        return SAMLIdentityProvider(idp_name, **idp_config)
+        enabled_idps: dict[str, dict] = self.setting("ENABLED_IDPS")
+        if idp_name is None:
+            # RelayState was missing, perhaps an IdP initiated flow
+            if len(enabled_idps) != 1:
+                raise AuthMissingParameter(self, "RelayState.idp")
+            # Use the only configured IDP
+            idp_name = next(iter(enabled_idps))
+        idp_config = enabled_idps[idp_name]
+        return SAMLIdentityProvider(self, idp_name, **idp_config)
 
-    def generate_saml_config(self, idp=None):
+    def generate_saml_config(self, idp: SAMLIdentityProvider | None = None):
         """
         Generate the configuration required to instantiate OneLogin_Saml2_Auth
         """
@@ -258,7 +348,7 @@ class SAMLAuth(BaseAuth):
         errors = saml_settings.validate_metadata(metadata)
         return metadata, errors
 
-    def _create_saml_auth(self, idp):
+    def _create_saml_auth(self, idp: SAMLIdentityProvider):
         """Get an instance of OneLogin_Saml2_Auth"""
         config = self.generate_saml_config(idp)
         request_info = {
@@ -286,6 +376,8 @@ class SAMLAuth(BaseAuth):
             "idp": idp_name,
             "next": self.data.get("next"),
         }
+        if session_id := self.strategy.get_session_id():
+            relay_state[self.strategy.SESSION_SAVE_KEY] = session_id
         return auth.login(return_to=json.dumps(relay_state))
 
     def get_user_details(self, response):
@@ -294,7 +386,7 @@ class SAMLAuth(BaseAuth):
         idp = self.get_idp(response["idp_name"])
         return idp.get_user_details(response["attributes"])
 
-    def get_user_id(self, details, response):
+    def get_user_id(self, details, response) -> str:
         """
         Get the permanent ID for this user from the response.
         We prefix each ID with the name of the IdP so that we can
@@ -309,24 +401,31 @@ class SAMLAuth(BaseAuth):
         The user has been redirected back from the IdP and we should
         now log them in, if everything checks out.
         """
+        idp_name: str | None
         try:
             relay_state_str = self.strategy.request_data()["RelayState"]
         except KeyError:
-            raise AuthMissingParameter(self, "RelayState")
-
-        try:
-            relay_state = json.loads(relay_state_str)
-            if not isinstance(relay_state, dict) or "idp" not in relay_state:
-                raise ValueError(
-                    "RelayState is expected to contain a JSON object with an 'idp' key"
-                )
-        except ValueError:
-            # Assume RelayState is just the idp_name, as it used to be in previous versions of this code.
-            # This ensures compatibility with previous versions.
-            idp_name = relay_state_str
+            idp_name = None
         else:
-            idp_name = relay_state["idp"]
-            if next_url := relay_state.get("next"):
+            # Parse RelayState JSON
+            try:
+                relay_state: dict = json.loads(relay_state_str)
+            except json.JSONDecodeError as error:
+                raise AuthInvalidParameter(self, "RelayState") from error
+
+            # Validate that the data is dict
+            if not isinstance(relay_state, dict):
+                raise AuthInvalidParameter(self, "RelayState")
+
+            # Get IdP name
+            idp_name = relay_state.get("idp")
+
+            if not idp_name:
+                raise AuthInvalidParameter(self, "RelayState.idp")
+
+            if session_id := relay_state.get(self.strategy.SESSION_SAVE_KEY):
+                self.strategy.restore_session(session_id, kwargs)
+            elif next_url := relay_state.get("next"):
                 # The do_complete action expects the "next" URL to be in session state or the request params.
                 self.strategy.session_set(kwargs.get("redirect_name", "next"), next_url)
 
@@ -349,9 +448,16 @@ class SAMLAuth(BaseAuth):
         kwargs.update({"response": response, "backend": self})
         return self.strategy.authenticate(*args, **kwargs)
 
-    def extra_data(self, user, uid, response, details=None, *args, **kwargs):
+    def extra_data(
+        self,
+        user,
+        uid: str,
+        response: dict[str, Any],
+        details: dict[str, Any],
+        pipeline_kwargs: dict[str, Any],
+    ) -> dict[str, Any]:
         extra_data = super().extra_data(
-            user, uid, response["attributes"], details=details, *args, **kwargs
+            user, uid, response["attributes"], details, pipeline_kwargs
         )
         extra_data["session_index"] = response["session_index"]
         extra_data["name_id"] = response["attributes"]["name_id"]
@@ -373,7 +479,7 @@ class SAMLAuth(BaseAuth):
         errors = auth.get_errors()
         return url, errors
 
-    def _check_entitlements(self, idp, attributes):
+    def _check_entitlements(self, idp, attributes) -> None:
         """
         Additional verification of a SAML response before
         authenticating the user.
