@@ -3,7 +3,8 @@ Twitter OAuth1 backend, docs at:
     https://python-social-auth.readthedocs.io/en/latest/backends/twitter.html
 """
 
-from ..exceptions import AuthCanceled
+from social_core.exceptions import AuthCanceled
+
 from .oauth import BaseOAuth1
 
 
@@ -18,7 +19,7 @@ class TwitterOAuth(BaseOAuth1):
     ACCESS_TOKEN_URL = "https://api.twitter.com/oauth/access_token"
     REDIRECT_STATE = True
 
-    def process_error(self, data):
+    def process_error(self, data) -> None:
         if "denied" in data:
             raise AuthCanceled(self)
         super().process_error(data)
