@@ -1,6 +1,7 @@
 from functools import wraps
 
-from ..utils import PARTIAL_TOKEN_SESSION_NAME
+from social_core.utils import PARTIAL_TOKEN_SESSION_NAME
+
 from .utils import partial_prepare
 
 
@@ -31,11 +32,11 @@ def partial_step(save_to_session):
 
             out = (
                 func(
+                    *args,
                     strategy=strategy,
                     backend=backend,
                     pipeline_index=pipeline_index,
                     current_partial=current_partial,
-                    *args,
                     **kwargs,
                 )
                 or {}
