@@ -7,49 +7,61 @@ import re
 import uuid
 from abc import abstractmethod
 from datetime import datetime, timedelta, timezone
-from typing import Any
+from typing import TYPE_CHECKING, Any, Protocol
 
 from openid.association import Association as OpenIdAssociation
 
 from .exceptions import MissingBackend
 
+if TYPE_CHECKING:
+    from social_core.backends.base import BaseAuth
+    from social_core.strategy import BaseStrategy
+
 NO_ASCII_REGEX = re.compile(r"[^\x00-\x7F]+")
 NO_SPECIAL_REGEX = re.compile(r"[^\w.@+_-]+", re.UNICODE)
 
 
+class UserProtocol(Protocol):
+    id: int
+    username: str
+
+
 class UserMixin:
     # Consider tokens that expire in 5 seconds as already expired
     ACCESS_TOKEN_EXPIRED_THRESHOLD = 5
 
     provider = ""
-    uid = None
-    extra_data = None
+    uid: str
+    user: UserProtocol
+    extra_data: dict[str, Any] | None = None
 
     @abstractmethod
     def save(self): ...
 
-    def get_backend(self, strategy):
+    def get_backend(self, strategy: BaseStrategy) -> type[BaseAuth]:
         return strategy.get_backend_class(self.provider)
 
-    def get_backend_instance(self, strategy):
+    def get_backend_instance(self, strategy: BaseStrategy) -> BaseAuth | None:
         try:
             return strategy.get_backend(self.provider)
         except MissingBackend:
             return None
 
     @property
-    def access_token(self):
+    def access_token(self) -> str | None:
         """Return access_token stored in extra_data or None"""
         return self.extra_data.get("access_token")
 
-    def refresh_token(self, strategy, *args, **kwargs):
+    def refresh_token(self, strategy: BaseStrategy, *args, **kwargs) -> None:
         token = self.extra_data.get("refresh_token") or self.extra_data.get(
             "access_token"
         )
         backend = self.get_backend_instance(strategy)
         if token and backend and hasattr(backend, "refresh_token"):
-            response = backend.refresh_token(token, *args, **kwargs)
-            extra_data = backend.extra_data(self, self.uid, response, self.extra_data)
+            response = backend.refresh_token(token, *args, **kwargs)  # type: ignore[attr-defined]
+            extra_data = backend.extra_data(
+                self.user, self.uid, response, self.extra_data or {}, {}
+            )
             if self.set_extra_data(extra_data):
                 self.save()
 
@@ -61,9 +73,9 @@ class UserMixin:
         timedelta is inferred from current time (using UTC timezone). None is
         returned if there's no value stored or it's invalid.
         """
-        if self.extra_data and "expires" in self.extra_data:
+        if self.extra_data and (expires := self.extra_data.get("expires")) is not None:
             try:
-                expires = int(self.extra_data.get("expires"))
+                expires = int(expires)
             except (ValueError, TypeError):
                 return None
 
@@ -96,49 +108,51 @@ class UserMixin:
             and expiration.total_seconds() <= self.ACCESS_TOKEN_EXPIRED_THRESHOLD
         )
 
-    def get_access_token(self, strategy):
+    def get_access_token(self, strategy: BaseStrategy) -> str | None:
         """Returns a valid access token."""
         if self.access_token_expired():
             self.refresh_token(strategy)
         return self.access_token
 
-    def set_extra_data(self, extra_data=None):
+    def set_extra_data(self, extra_data: dict[str, Any] | None = None) -> bool:
         if extra_data and self.extra_data != extra_data:
             if self.extra_data and not isinstance(self.extra_data, str):
                 self.extra_data.update(extra_data)
             else:
                 self.extra_data = extra_data
             return True
-        return None
+        return False
 
     @classmethod
-    def clean_username(cls, value):
+    def clean_username(cls, value: str) -> str:
         """Clean username removing any unsupported character"""
         value = NO_ASCII_REGEX.sub("", value)
         return NO_SPECIAL_REGEX.sub("", value)
 
     @classmethod
-    def changed(cls, user):
+    def changed(cls, user: UserProtocol) -> None:
         """The given user instance is ready to be saved"""
         raise NotImplementedError("Implement in subclass")
 
     @classmethod
-    def get_username(cls, user):
+    def get_username(cls, user: UserProtocol) -> str:
         """Return the username for given user"""
         raise NotImplementedError("Implement in subclass")
 
     @classmethod
-    def user_model(cls):
+    def user_model(cls) -> type[UserProtocol]:
         """Return the user model"""
         raise NotImplementedError("Implement in subclass")
 
     @classmethod
-    def username_max_length(cls):
+    def username_max_length(cls) -> int:
         """Return the max length for username"""
         raise NotImplementedError("Implement in subclass")
 
     @classmethod
-    def allowed_to_disconnect(cls, user, backend_name, association_id=None):
+    def allowed_to_disconnect(
+        cls, user: UserProtocol, backend_name: str, association_id=None
+    ) -> bool:
         """Return if it's safe to disconnect the social account for the
         given user"""
         raise NotImplementedError("Implement in subclass")
@@ -149,7 +163,7 @@ class UserMixin:
         raise NotImplementedError("Implement in subclass")
 
     @classmethod
-    def user_exists(cls, *args, **kwargs):
+    def user_exists(cls, *args, **kwargs) -> bool:
         """
         Return True/False if a User instance exists with the given arguments.
         Arguments are directly passed to filter() manager method.
@@ -167,22 +181,27 @@ class UserMixin:
         raise NotImplementedError("Implement in subclass")
 
     @classmethod
-    def get_users_by_email(cls, email):
+    def get_users_by_email(cls, email: str):
         """Return users instances for given email address"""
         raise NotImplementedError("Implement in subclass")
 
     @classmethod
-    def get_social_auth(cls, provider, uid):
+    def get_social_auth(cls, provider: str, uid: int):
         """Return UserSocialAuth for given provider and uid"""
         raise NotImplementedError("Implement in subclass")
 
     @classmethod
-    def get_social_auth_for_user(cls, user, provider=None, id=None):
+    def get_social_auth_for_user(
+        cls,
+        user: UserProtocol,
+        provider: str | None = None,
+        id: int | None = None,  # noqa: A002
+    ):
         """Return all the UserSocialAuth instances for given user"""
         raise NotImplementedError("Implement in subclass")
 
     @classmethod
-    def create_social_auth(cls, user, uid, provider):
+    def create_social_auth(cls, user: UserProtocol, uid: int, provider: str):
         """Create a UserSocialAuth instance for given user"""
         raise NotImplementedError("Implement in subclass")
 
@@ -268,7 +287,7 @@ class CodeMixin:
     @abstractmethod
     def save(self): ...
 
-    def verify(self):
+    def verify(self) -> None:
         self.verified = True
         self.save()
 
@@ -277,7 +296,7 @@ class CodeMixin:
         return uuid.uuid4().hex
 
     @classmethod
-    def make_code(cls, email):
+    def make_code(cls, email: str) -> CodeMixin:
         code = cls()
         code.email = email
         code.code = cls.generate_code()
@@ -301,7 +320,7 @@ class PartialMixin:
         return self.data.get("args", [])
 
     @args.setter
-    def args(self, value):
+    def args(self, value) -> None:
         self.data["args"] = value
 
     @property
@@ -309,10 +328,10 @@ class PartialMixin:
         return self.data.get("kwargs", {})
 
     @kwargs.setter
-    def kwargs(self, value):
+    def kwargs(self, value) -> None:
         self.data["kwargs"] = value
 
-    def extend_kwargs(self, values):
+    def extend_kwargs(self, values) -> None:
         self.data["kwargs"].update(values)
 
     @classmethod
@@ -350,6 +369,6 @@ class BaseStorage:
     partial = PartialMixin
 
     @classmethod
-    def is_integrity_error(cls, exception):
+    def is_integrity_error(cls, exception) -> bool:
         """Check if given exception flags an integrity error in the DB"""
         raise NotImplementedError("Implement in subclass")
