@@ -1,42 +1,52 @@
 from __future__ import annotations
 
 import secrets
-from typing import TYPE_CHECKING
+from typing import TYPE_CHECKING, Any, cast
 
 from .backends.utils import get_backend
+from .exceptions import StrategyMissingFeatureError
 from .pipeline import DEFAULT_AUTH_PIPELINE, DEFAULT_DISCONNECT_PIPELINE
-from .pipeline.utils import partial_load, partial_prepare, partial_store
+from .pipeline.utils import partial_load
 from .store import OpenIdSessionWrapper, OpenIdStore
 from .utils import PARTIAL_TOKEN_SESSION_NAME, module_member, setting_name
 
 if TYPE_CHECKING:
     from .backends.base import BaseAuth
+    from .storage import BaseStorage, CodeMixin
 
 
 class BaseTemplateStrategy:
-    def __init__(self, strategy):
+    def __init__(self, strategy) -> None:
         self.strategy = strategy
 
-    def render(self, tpl=None, html=None, context=None):
-        if not tpl and not html:
-            raise ValueError("Missing template or html parameters")
+    def render(
+        self,
+        tpl: str | None = None,
+        html: str | None = None,
+        context: dict[str, Any] | None = None,
+    ) -> str:
         context = context or {}
         if tpl:
             return self.render_template(tpl, context)
+        if not html:
+            raise ValueError("Missing template or html parameters")
         return self.render_string(html, context)
 
-    def render_template(self, tpl, context):
+    def render_template(self, tpl: str, context: dict[str, Any] | None) -> str:
         raise NotImplementedError("Implement in subclass")
 
-    def render_string(self, html, context):
+    def render_string(self, html: str, context: dict[str, Any] | None) -> str:
         raise NotImplementedError("Implement in subclass")
 
 
 class BaseStrategy:
     ALLOWED_CHARS = "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789"
     DEFAULT_TEMPLATE_STRATEGY = BaseTemplateStrategy
+    SESSION_SAVE_KEY = "psa_session_id"
 
-    def __init__(self, storage=None, tpl=None):
+    def __init__(
+        self, storage: type[BaseStorage], tpl: type[BaseTemplateStrategy] | None = None
+    ) -> None:
         self.storage = storage
         self.tpl = (tpl or self.DEFAULT_TEMPLATE_STRATEGY)(self)
 
@@ -61,6 +71,20 @@ class BaseStrategy:
         self.session_set(name, value)
         return self.session_get(name)
 
+    def get_session_id(self) -> str | None:
+        """
+        Return session ID to be used by restore_session.
+        """
+        return None
+
+    def restore_session(self, session_id: str, kwargs: dict[str, Any]) -> None:
+        """
+        Restores session and updates kwargs to match it.
+
+        This is only called if get_session_id returns a value.
+        """
+        raise StrategyMissingFeatureError(self.__class__.__name__, "session restore")
+
     def openid_session_dict(self, name):
         # Many frameworks are switching the session serialization from Pickle
         # to JSON to avoid code execution risks. Flask did this from Flask
@@ -83,16 +107,10 @@ class BaseStrategy:
     def from_session_value(self, val):
         return val
 
-    def partial_save(self, next_step, backend: BaseAuth, *args, **kwargs):
-        return partial_store(self, backend, next_step, *args, **kwargs)
-
-    def partial_prepare(self, next_step, backend: BaseAuth, *args, **kwargs):
-        return partial_prepare(self, backend, next_step, *args, **kwargs)
-
     def partial_load(self, token):
         return partial_load(self, token)
 
-    def clean_partial_pipeline(self, token):
+    def clean_partial_pipeline(self, token) -> None:
         self.storage.partial.destroy(token)
         current_token_in_session = self.session_get(PARTIAL_TOKEN_SESSION_NAME)
         if current_token_in_session == token:
@@ -101,11 +119,16 @@ class BaseStrategy:
     def openid_store(self):
         return OpenIdStore(self)
 
-    def get_pipeline(self, backend: BaseAuth | None = None):
-        return self.setting("PIPELINE", DEFAULT_AUTH_PIPELINE, backend)
+    def get_pipeline(self, backend: BaseAuth | None = None) -> list[str]:
+        return cast(
+            "list[str]", self.setting("PIPELINE", DEFAULT_AUTH_PIPELINE, backend)
+        )
 
-    def get_disconnect_pipeline(self, backend: BaseAuth | None = None):
-        return self.setting("DISCONNECT_PIPELINE", DEFAULT_DISCONNECT_PIPELINE, backend)
+    def get_disconnect_pipeline(self, backend: BaseAuth | None = None) -> list[str]:
+        return cast(
+            "list[str]",
+            self.setting("DISCONNECT_PIPELINE", DEFAULT_DISCONNECT_PIPELINE, backend),
+        )
 
     def random_string(self, length: int = 12, chars: str = ALLOWED_CHARS) -> str:
         return "".join([secrets.choice(chars) for i in range(length)])
@@ -116,13 +139,13 @@ class BaseStrategy:
             uri = uri.replace("http://", "https://")
         return uri
 
-    def get_language(self):
+    def get_language(self) -> str:
         """Return current language"""
         return ""
 
     def send_email_validation(
         self, backend: BaseAuth, email: str, partial_token: str | None = None
-    ) -> str:
+    ) -> CodeMixin:
         email_validation = self.setting("EMAIL_VALIDATION_FUNCTION")
         send_email = module_member(email_validation)
         code = self.storage.code.make_code(email)
@@ -140,7 +163,12 @@ class BaseStrategy:
         verification_code.verify()
         return True
 
-    def render_html(self, tpl=None, html=None, context=None):
+    def render_html(
+        self,
+        tpl: str | None = None,
+        html: str | None = None,
+        context: dict[str, Any] | None = None,
+    ) -> str:
         """Render given template or raw html with given context"""
         return self.tpl.render(tpl, html, context)
 
@@ -158,18 +186,20 @@ class BaseStrategy:
         of them"""
         return args, kwargs
 
-    def get_backends(self):
+    def get_backends(self) -> list[str]:
         """Return configured backends"""
-        return self.setting("AUTHENTICATION_BACKENDS", [])
+        return cast("list[str]", self.setting("AUTHENTICATION_BACKENDS", []))
 
-    def get_backend_class(self, name):
+    def get_backend_class(self, name: str) -> type[BaseAuth]:
         """Return a configured backend class"""
         return get_backend(self.get_backends(), name)
 
-    def get_backend(self, name, redirect_uri=None, *args, **kwargs):
+    def get_backend(
+        self, name: str, redirect_uri: str | None = None, *args, **kwargs
+    ) -> BaseAuth:
         """Return a configured backend instance"""
         Backend = self.get_backend_class(name)
-        return Backend(self, redirect_uri=redirect_uri, *args, **kwargs)
+        return Backend(self, *args, redirect_uri=redirect_uri, **kwargs)
 
     # Implement the following methods on strategies sub-classes
 
@@ -189,7 +219,7 @@ class BaseStrategy:
         """Return current request data (POST or GET)"""
         raise NotImplementedError("Implement in subclass")
 
-    def request_host(self):
+    def request_host(self) -> str:
         """Return current host value"""
         raise NotImplementedError("Implement in subclass")
 
@@ -205,19 +235,19 @@ class BaseStrategy:
         """Pop session value for given key"""
         raise NotImplementedError("Implement in subclass")
 
-    def build_absolute_uri(self, path=None):
+    def build_absolute_uri(self, path: str | None = None) -> str:
         """Build absolute URI with given (optional) path"""
         raise NotImplementedError("Implement in subclass")
 
-    def request_is_secure(self):
+    def request_is_secure(self) -> bool:
         """Is the request using HTTPS?"""
         raise NotImplementedError("Implement in subclass")
 
-    def request_path(self):
+    def request_path(self) -> str:
         """path of the current request"""
         raise NotImplementedError("Implement in subclass")
 
-    def request_port(self):
+    def request_port(self) -> int:
         """Port in use for this request"""
         raise NotImplementedError("Implement in subclass")
 
