@@ -7,9 +7,10 @@ from urllib.parse import urlparse
 import requests
 import responses
 
-from ...backends.oauth import BaseOAuth1, BaseOAuth2, OAuthAuth
-from ...utils import get_querystring, parse_qs, url_add_parameters
-from ..models import User
+from social_core.backends.oauth import BaseOAuth1, BaseOAuth2, OAuthAuth
+from social_core.tests.models import User
+from social_core.utils import get_querystring, parse_qs, url_add_parameters
+
 from .base import BaseBackendTest
 
 OAuthBackendT = TypeVar("OAuthBackendT", bound=OAuthAuth)
@@ -23,7 +24,7 @@ class BaseOAuthTest(BaseBackendTest[OAuthBackendT], Generic[OAuthBackendT]):
     access_token_body: str | None = None
     access_token_status: int = 200
 
-    def extra_settings(self):
+    def extra_settings(self) -> dict[str, str | list[str]]:
         assert self.name, "Subclasses must set the name attribute"
         return {
             "SOCIAL_AUTH_" + self.name + "_KEY": "a-key",
@@ -68,7 +69,7 @@ class BaseOAuthTest(BaseBackendTest[OAuthBackendT], Generic[OAuthBackendT]):
             )
         return target_url
 
-    def pre_complete_callback(self, start_url):
+    def pre_complete_callback(self, start_url) -> None:
         responses.add(
             self._method(self.backend.ACCESS_TOKEN_METHOD),
             url=self.backend.access_token_url(),
@@ -100,7 +101,7 @@ class OAuth1Test(BaseOAuthTest[BaseOAuth1BackendT], Generic[BaseOAuth1BackendT])
     request_token_body: str
     raw_complete_url = "/complete/{0}/?oauth_verifier=bazqux&oauth_token=foobar"
 
-    def request_token_handler(self):
+    def request_token_handler(self) -> None:
         assert self.request_token_body, "Subclasses must set request_token_body"
         responses.add(
             self._method(self.backend.REQUEST_TOKEN_METHOD),
@@ -152,7 +153,7 @@ class OAuth2PkcePlainTest(OAuth2Test):
         auth_request = next(
             r.request
             for r in responses.calls
-            if r.request.url.startswith(self.backend.authorization_url())
+            if cast("str", r.request.url).startswith(self.backend.authorization_url())
         )
         code_challenge = get_querystring(cast("str", auth_request.url)).get(
             "code_challenge"
@@ -166,7 +167,7 @@ class OAuth2PkcePlainTest(OAuth2Test):
         auth_complete = next(
             r.request
             for r in responses.calls
-            if r.request.url.startswith(self.backend.access_token_url())
+            if cast("str", r.request.url).startswith(self.backend.access_token_url())
         )
         code_verifier = parse_qs(auth_complete.body).get("code_verifier")
         self.assertEqual(code_challenge, code_verifier)
@@ -182,7 +183,7 @@ class OAuth2PkceS256Test(OAuth2Test):
         auth_request = next(
             r.request
             for r in responses.calls
-            if r.request.url.startswith(self.backend.authorization_url())
+            if cast("str", r.request.url).startswith(self.backend.authorization_url())
         )
         code_challenge = get_querystring(cast("str", auth_request.url)).get(
             "code_challenge"
@@ -196,7 +197,7 @@ class OAuth2PkceS256Test(OAuth2Test):
         auth_complete = next(
             r.request
             for r in responses.calls
-            if r.request.url.startswith(self.backend.access_token_url())
+            if cast("str", r.request.url).startswith(self.backend.access_token_url())
         )
         code_verifier = parse_qs(auth_complete.body).get("code_verifier")
         self.assertEqual(
@@ -210,7 +211,9 @@ class OAuth2PkceS256Test(OAuth2Test):
 class BaseAuthUrlTestMixin(Generic[OAuthBackendT]):
     backend: OAuthBackendT
 
-    def check_parameters_in_authorization_url(self, auth_url_key="AUTHORIZATION_URL"):
+    def check_parameters_in_authorization_url(
+        self, auth_url_key="AUTHORIZATION_URL"
+    ) -> None:
         """
         Check the parameters in authorization url
 
@@ -235,11 +238,11 @@ class BaseAuthUrlTestMixin(Generic[OAuthBackendT]):
             # we expect an & symbol to join the different parameters
             assert "?param1=value1&param2=value2&" in self.backend.auth_url()
 
-    def test_auth_url_parameters(self):
+    def test_auth_url_parameters(self) -> None:
         self.check_parameters_in_authorization_url()
 
 
 class OAuth1AuthUrlTestMixin(BaseAuthUrlTestMixin):
-    def test_auth_url_parameters(self):
+    def test_auth_url_parameters(self) -> None:
         self.request_token_handler()  # type: ignore[attr-defined]
         self.check_parameters_in_authorization_url()
