@@ -51,8 +51,8 @@ class AtlassianOAuth2Test(OAuth2Test, BaseAuthUrlTestMixin):
         )
         return target_url
 
-    def test_login(self):
+    def test_login(self) -> None:
         self.do_login()
 
-    def test_partial_pipeline(self):
+    def test_partial_pipeline(self) -> None:
         self.do_partial_pipeline()
