@@ -10,8 +10,8 @@ class DailymotionOAuth2Test(OAuth2Test, BaseAuthUrlTestMixin):
     access_token_body = json.dumps({"access_token": "foobar", "token_type": "bearer"})
     user_data_body = json.dumps({"id": "foobar", "screenname": "foobar"})
 
-    def test_login(self):
+    def test_login(self) -> None:
         self.do_login()
 
-    def test_partial_pipeline(self):
+    def test_partial_pipeline(self) -> None:
         self.do_partial_pipeline()
