@@ -14,8 +14,8 @@ class DribbbleOAuth2Test(OAuth2Test, BaseAuthUrlTestMixin):
         {"id": "foobar", "username": "foobar", "name": "Foo Bar"}
     )
 
-    def test_login(self):
+    def test_login(self) -> None:
         self.do_login()
 
-    def test_partial_pipeline(self):
+    def test_partial_pipeline(self) -> None:
         self.do_partial_pipeline()
