@@ -15,8 +15,8 @@ class DripOAuthTest(OAuth2Test, BaseAuthUrlTestMixin):
         {"users": [{"email": "other@example.com", "name": None}]}
     )
 
-    def test_login(self):
+    def test_login(self) -> None:
         self.do_login()
 
-    def test_partial_pipeline(self):
+    def test_partial_pipeline(self) -> None:
         self.do_partial_pipeline()
