@@ -17,8 +17,8 @@ class GrafanaOAuth2Test(OAuth2Test, BaseAuthUrlTestMixin):
     )
     expected_username = "fooboy"
 
-    def test_login(self):
+    def test_login(self) -> None:
         self.do_login()
 
-    def test_partial_pipeline(self):
+    def test_partial_pipeline(self) -> None:
         self.do_partial_pipeline()
