@@ -19,8 +19,8 @@ class SimpleLoginOAuth2Test(OAuth2Test, BaseAuthUrlTestMixin):
     )
     expected_username = "john@wick.com"
 
-    def test_login(self):
+    def test_login(self) -> None:
         self.do_login()
 
-    def test_partial_pipeline(self):
+    def test_partial_pipeline(self) -> None:
         self.do_partial_pipeline()
