@@ -25,8 +25,8 @@ class DatagouvfrOAuth2Test(OAuth2Test, BaseAuthUrlTestMixin):
     )
     user_data_body = json.dumps({})
 
-    def test_login(self):
+    def test_login(self) -> None:
         self.do_login()
 
-    def test_partial_pipeline(self):
+    def test_partial_pipeline(self) -> None:
         self.do_partial_pipeline()
