@@ -1,7 +1,7 @@
 import unittest
 
-from ..backends.base import BaseAuth
-from ..exceptions import (
+from social_core.backends.base import BaseAuth
+from social_core.exceptions import (
     AuthAlreadyAssociated,
     AuthCanceled,
     AuthException,
@@ -20,6 +20,7 @@ from ..exceptions import (
     SocialAuthBaseException,
     WrongBackend,
 )
+
 from .models import TestStorage
 from .strategy import TestStrategy
 
@@ -28,7 +29,7 @@ class BaseExceptionTestCase(unittest.TestCase):
     exception: SocialAuthBaseException = SocialAuthBaseException("base test")
     expected_message: str = "base test"
 
-    def test_exception_message(self):
+    def test_exception_message(self) -> None:
         try:
             raise self.exception
         except SocialAuthBaseException as err:
