@@ -1,5 +1,6 @@
 from __future__ import annotations
 
+import contextlib
 import functools
 import hmac
 import logging
@@ -7,7 +8,7 @@ import re
 import sys
 import time
 import unicodedata
-from typing import Any
+from typing import TYPE_CHECKING, Any
 from urllib.parse import parse_qs as battery_parse_qs
 from urllib.parse import unquote, urlencode, urlparse, urlunparse
 
@@ -15,7 +16,15 @@ import requests
 
 import social_core
 
-from .exceptions import AuthCanceled, AuthForbidden, AuthUnreachableProvider
+from .exceptions import (
+    AuthCanceled,
+    AuthForbidden,
+    AuthTokenError,
+    AuthUnreachableProvider,
+)
+
+if TYPE_CHECKING:
+    from social_core.backends.base import BaseAuth
 
 SETTING_PREFIX = "SOCIAL_AUTH"
 
@@ -52,7 +61,7 @@ def url_add_parameters(
         fragments[4] = urlencode(value)
         if _unquote_query:
             fragments[4] = unquote(fragments[4])
-        url = urlunparse(fragments)
+        url = urlunparse(fragments)  # ty: ignore[invalid-assignment]
     return url
 
 
@@ -251,6 +260,16 @@ def handle_http_errors(func):
     return wrapper
 
 
+@contextlib.contextmanager
+def wrap_access_token_error(backend: BaseAuth):
+    try:
+        yield
+    except requests.HTTPError as error:
+        if error.response.status_code == 401:
+            raise AuthTokenError(backend, "Invalid key/secret, perhaps expired")
+        raise
+
+
 def append_slash(url):
     """Make sure we append a slash at the end of the URL otherwise we
     have issues with urljoin Example:
@@ -279,7 +298,7 @@ class cache:
     Does not work for methods with arguments.
     """
 
-    def __init__(self, ttl: int):
+    def __init__(self, ttl: int) -> None:
         self.ttl = ttl
         self.cache: dict[type, Any] = {}
 
@@ -306,5 +325,5 @@ class cache:
         wrapped.invalidate = self._invalidate  # type: ignore[attr-defined]
         return wrapped
 
-    def _invalidate(self):
+    def _invalidate(self) -> None:
         self.cache.clear()
